==> zio-aws-docdb_2.13-5.17.150.1-sources.jar: zio/aws/docdb/model/DescribeDbClustersResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeDbClustersResponse(
    marker: Option[String] = None,
    dbClusters: Option[Iterable[zio.aws.docdb.model.DBCluster]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DescribeDbClustersResponse = {
    import DescribeDbClustersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DescribeDbClustersResponse
      .builder()
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(
        dbClusters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.dbClusters)
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.DescribeDbClustersResponse.ReadOnly =
    zio.aws.docdb.model.DescribeDbClustersResponse.wrap(buildAwsValue())
}
object DescribeDbClustersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DescribeDbClustersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.DescribeDbClustersResponse =
      zio.aws.docdb.model.DescribeDbClustersResponse(
        marker.map(value => value),
        dbClusters.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: Option[String]
    def dbClusters: Option[List[zio.aws.docdb.model.DBCluster.ReadOnly]]
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getDbClusters
        : ZIO[Any, AwsError, List[zio.aws.docdb.model.DBCluster.ReadOnly]] =
      AwsError.unwrapOptionField("dbClusters", dbClusters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DescribeDbClustersResponse
  ) extends zio.aws.docdb.model.DescribeDbClustersResponse.ReadOnly {
    override val marker: Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
    override val dbClusters
        : Option[List[zio.aws.docdb.model.DBCluster.ReadOnly]] = scala
      .Option(impl.dbClusters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.docdb.model.DBCluster.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DescribeDbClustersResponse
  ): zio.aws.docdb.model.DescribeDbClustersResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-docdb_2.13-6.20.61.1-sources.jar: zio/aws/docdb/model/DescribeDbClustersResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeDbClustersResponse(
    marker: Optional[String] = Optional.Absent,
    dbClusters: Optional[Iterable[zio.aws.docdb.model.DBCluster]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DescribeDbClustersResponse = {
    import DescribeDbClustersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DescribeDbClustersResponse
      .builder()
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(
        dbClusters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.dbClusters)
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.DescribeDbClustersResponse.ReadOnly =
    zio.aws.docdb.model.DescribeDbClustersResponse.wrap(buildAwsValue())
}
object DescribeDbClustersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DescribeDbClustersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.DescribeDbClustersResponse =
      zio.aws.docdb.model.DescribeDbClustersResponse(
        marker.map(value => value),
        dbClusters.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: Optional[String]
    def dbClusters: Optional[List[zio.aws.docdb.model.DBCluster.ReadOnly]]
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getDbClusters
        : ZIO[Any, AwsError, List[zio.aws.docdb.model.DBCluster.ReadOnly]] =
      AwsError.unwrapOptionField("dbClusters", dbClusters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DescribeDbClustersResponse
  ) extends zio.aws.docdb.model.DescribeDbClustersResponse.ReadOnly {
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
    override val dbClusters
        : Optional[List[zio.aws.docdb.model.DBCluster.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbClusters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.docdb.model.DBCluster.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DescribeDbClustersResponse
  ): zio.aws.docdb.model.DescribeDbClustersResponse.ReadOnly = new Wrapper(impl)
}
